@@ -4,7 +4,7 @@ from aind_data_schema.imaging.instrument import (AdditionalImagingDevice, Com, D
 
 inst = Instrument(
     instrument_id="SmartSPIM1-1",
-    type="smartSPIM",
+    instrument_type="SmartSPIM",
     manufacturer="LifeCanvas",
     location="440 Westlake",
     objectives=[
