@@ -4,7 +4,8 @@ import datetime
 import json
 import unittest
 
-from aind_data_schema.data_description import DataDescription, DerivedDataDescription, Funding, RawDataDescription
+from aind_data_schema.data_description import (DataDescription, DerivedDataDescription, Funding, Institution, Modality,
+                                               RawDataDescription)
 
 
 class DataDescriptionTest(unittest.TestCase):
@@ -14,97 +15,6 @@ class DataDescriptionTest(unittest.TestCase):
     BASIC_NAME = "ecephys_1234_3033-12-21_04-22-11"
     DERIVED_NAME = "ecephys_1234_3033-12-21_04-22-11_spikesorted-ks25_2022-10-12_23-23-11"
 
-    def test_from_name(self):
-        """test the from_name methods"""
-
-        f = Funding(funder="test")
-
-        da = DataDescription.from_name(
-            name=self.BASIC_NAME,
-            institution="AIND",
-            data_level="raw data",
-            funding_source=[f],
-            modality="exaSPIM",
-            subject_id="12345",
-        )
-        assert da.name == self.BASIC_NAME
-
-        with self.assertRaises(ValueError):
-            DataDescription.from_name(
-                name=self.BAD_NAME,
-                institution="AIND",
-                data_level="raw data",
-                funding_source=[f],
-            )
-
-        rd = RawDataDescription.from_name(name=self.BASIC_NAME, institution="AIND", funding_source=[f])
-        assert rd.name == self.BASIC_NAME
-        assert rd.data_level.value == "raw data"
-
-        with self.assertRaises(ValueError):
-            RawDataDescription.from_name(
-                name=self.BAD_NAME,
-                institution="AIND",
-                data_level="raw data",
-                funding_source=[f],
-            )
-
-        dd = DerivedDataDescription.from_name(
-            name=self.DERIVED_NAME,
-            institution="AIND",
-            funding_source=[f],
-            modality="SmartSPIM",
-            subject_id="12345",
-        )
-        assert dd.name == self.DERIVED_NAME
-        assert dd.data_level.value == "derived data"
-
-        with self.assertRaises(ValueError):
-            DerivedDataDescription.from_name(
-                name=self.BAD_NAME,
-                institution="AIND",
-                data_level="raw data",
-                funding_source=[f],
-            )
-
-    def test_from_data_description(self):
-        """test the from_data_description method"""
-        dt = datetime.datetime.now()
-        d1 = RawDataDescription(
-            creation_date=dt.date(),
-            creation_time=dt.time(),
-            institution="AIND",
-            data_level="raw data",
-            funding_source=[],
-            modality="ecephys",
-            subject_id="12345",
-        )
-
-        dt = datetime.datetime.now()
-        d2 = DerivedDataDescription.from_data_description(
-            input_data=d1,
-            process_name="fishing",
-            creation_date=dt.date(),
-            creation_time=dt.time(),
-            institution="AIND",
-            funding_source=[],
-        )
-
-        assert d2.modality == d1.modality
-        assert d2.subject_id == d1.subject_id
-
-        d3 = DerivedDataDescription.from_data_description(
-            input_data=d2,
-            process_name="bailing",
-            creation_date=dt.date(),
-            creation_time=dt.time(),
-            institution="HUST",
-            funding_source=[],
-        )
-
-        assert d3.modality == d2.modality
-        assert d3.subject_id == d2.subject_id
-
     def test_constructors(self):
         """test building from component parts"""
         f = Funding(funder="test")
@@ -113,10 +23,11 @@ class DataDescriptionTest(unittest.TestCase):
         da = RawDataDescription(
             creation_date=dt.date(),
             creation_time=dt.time(),
-            institution="AIND",
+            institution=Institution.AIND,
             data_level="raw data",
             funding_source=[f],
-            modality="ecephys",
+            modality=[Modality.ECEPHYS],
+            experiment_type="ecephys",
             subject_id="12345",
         )
 
@@ -125,9 +36,10 @@ class DataDescriptionTest(unittest.TestCase):
             process_name="spikesort-ks25",
             creation_date=dt.date(),
             creation_time=dt.time(),
-            institution="AIND",
+            institution=Institution.AIND,
             funding_source=[f],
             modality=da.modality,
+            experiment_type=da.experiment_type,
             subject_id=da.subject_id,
         )
 
@@ -136,9 +48,10 @@ class DataDescriptionTest(unittest.TestCase):
             process_name="some-model",
             creation_date=dt.date(),
             creation_time=dt.time(),
-            institution="AIND",
+            institution=Institution.AIND,
             funding_source=[f],
-            modality="ecephys",
+            modality=r1.modality,
+            experiment_type=r1.experiment_type,
             subject_id="12345",
         )
 
@@ -147,21 +60,23 @@ class DataDescriptionTest(unittest.TestCase):
             process_name="a-paper",
             creation_date=dt.date(),
             creation_time=dt.time(),
-            institution="AIND",
+            institution=Institution.AIND,
             funding_source=[f],
-            modality="ecephys",
+            modality=r2.modality,
+            experiment_type=r2.experiment_type,
             subject_id="12345",
         )
         assert r3 is not None
 
         dd = DataDescription(
             label="test_data",
-            modality="ecephys",
+            modality=[Modality.SPIM],
+            experiment_type="exaSPIM",
             subject_id="1234",
             data_level="raw data",
             creation_date=dt.date(),
             creation_time=dt.time(),
-            institution="AIND",
+            institution=Institution.AIND,
             funding_source=[f],
         )
 
@@ -175,10 +90,11 @@ class DataDescriptionTest(unittest.TestCase):
         da1 = RawDataDescription(
             creation_date=dt.date(),
             creation_time=dt.time(),
-            institution="AIND",
+            institution=Institution.AIND,
             data_level="raw data",
             funding_source=[],
-            modality="ecephys",
+            modality=[Modality.SPIM],
+            experiment_type="exaSPIM",
             subject_id="12345",
         )
 
@@ -188,6 +104,35 @@ class DataDescriptionTest(unittest.TestCase):
         assert da1.creation_date == da2.creation_date
         assert da1.name == da2.name
 
+    def test_parse_name(self):
+        """tests for parsing names"""
+
+        toks = DataDescription.parse_name(self.BASIC_NAME)
+        assert toks["label"] == "ecephys_1234"
+        assert toks["creation_date"] == datetime.date(3033, 12, 21)
+        assert toks["creation_time"] == datetime.time(4, 22, 11)
+
+        with self.assertRaises(ValueError):
+            toks = DataDescription.parse_name(self.BAD_NAME)
+
+        toks = RawDataDescription.parse_name(self.BASIC_NAME)
+        assert toks["experiment_type"] == "ecephys"
+        assert toks["subject_id"] == "1234"
+        assert toks["creation_date"] == datetime.date(3033, 12, 21)
+        assert toks["creation_time"] == datetime.time(4, 22, 11)
+
+        with self.assertRaises(ValueError):
+            toks = RawDataDescription.parse_name(self.BAD_NAME)
+
+        toks = DerivedDataDescription.parse_name(self.DERIVED_NAME)
+        assert toks["input_data_name"] == "ecephys_1234_3033-12-21_04-22-11"
+        assert toks["process_name"] == "spikesorted-ks25"
+        assert toks["creation_date"] == datetime.date(2022, 10, 12)
+        assert toks["creation_time"] == datetime.time(23, 23, 11)
+
+        with self.assertRaises(ValueError):
+            toks = DerivedDataDescription.parse_name(self.BAD_NAME)
+
 
 if __name__ == "__main__":
     unittest.main()
